@@ -1,6 +1,6 @@
 package Crypt::Passphrase::MD5::Hex;
-$Crypt::Passphrase::MD5::Hex::VERSION = '0.009';
-use parent 'Crypt::Passphrase::Validator';
+$Crypt::Passphrase::MD5::Hex::VERSION = '0.010';
+use Crypt::Passphrase -validator;
 
 use Digest::MD5 'md5_hex';
 
@@ -35,7 +35,7 @@ Crypt::Passphrase::MD5::Hex - Validate against hexed MD5 hashes with Crypt::Pass
 
 =head1 VERSION
 
-version 0.009
+version 0.010
 
 =head1 DESCRIPTION
 
